@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A YAML converting processor
 
-our $VERSION = '1.111810'; # VERSION
+our $VERSION = '1.112100';    # VERSION
 
 use Moose;
 extends 'DataFlow::Proc::Converter';
@@ -33,7 +33,6 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-
 __END__
 =pod
 
@@ -45,7 +44,7 @@ DataFlow::Proc::YAML - A YAML converting processor
 
 =head1 VERSION
 
-version 1.111810
+version 1.112100
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
 
@@ -155,9 +154,9 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://github.com/russoz/DataFlow-Proc-YAML>
+L<https://github.com/russoz/DataFlow-Proc-YAML>
 
-  git clone http://github.com/russoz/DataFlow-Proc-YAML
+  git clone https://github.com/russoz/DataFlow-Proc-YAML
 
 =head1 AUTHOR
 
